﻿-- Thomas Elliott
-- Version: 1.4 - Release	
-- 9/13/2012

-- Creates Ace Object
PlayerFrameRemoval = LibStub("AceAddon-3.0"):NewAddon("PlayerFrameRemoval", "AceConsole-3.0")

-- Creates options menue for toggling visibility of player frame

local options = {
	name = "PlayerFrameRemoval",
	handler = PlayerFrameRemoval,
	type = 'group',
	args = {
		togglepf = {
			type = "execute",
			name = "Toggle Player Frame",
			desc = "Toggles player frame visibility.",
			func = "togPlayer",
		},	
		status = {
			type = "execute",
			name = "Player Frame Status",
			desc = "Displays visibility status on screen.",
			func = "status",
		},	
		toggletf = {
			type = "execute",
			name = "Toggle Target Frame",
			desc = "Toggles target frame visibility",
			func = "togTarget",
		},	
	},
}

-- Sets a default value for visibility when run for the first time on a profile
local defaults = {
	char = {
		visible = true,
		pfVisible = true,
		tfVisible = true,
		firstTime = 0,
	},
}

-- When the addon is loaded it creates a new AceDB if it doesn't already exist, registers the options table, and prints welcome message
function PlayerFrameRemoval:OnInitialize()
	
	self.db = LibStub("AceDB-3.0"):New("PFRDB", defaults, "Default")

	LibStub("AceConfig-3.0"):RegisterOptionsTable("PlayerFrameRemoval", options, {"playerframeremoval", "pfr"})
	
	self:Print("Thank you for using Player Frame Removal questions/comments/bugs feel free to email: tmelliottjr@yahoo.com \n Use the command /pfr for a list of options.")
	
	-- This tests whether or not this is the first time they have run this update (1.3) If it is it copies over the old settings if not it does nothing.
	if self.db.char.firstTime == 0 then
		self.db.char.pfVisible = self.db.char.visible
		self.db.char.firstTime = 1
		self:Print("Settings Update Complete")
	end
	
	-- Tests whether or not the saved variable is true or false to determine visibility of player frame
	if self.db.char.pfVisible then
		PlayerFrame:Show()
		PlayerFrame:SetScript("OnEvent", PlayerFrame_OnEvent);
	else 
		PlayerFrame:Hide()
		PlayerFrame:SetScript("OnEvent", nil);
	end
	
	-- Tests whether or not the saved variable is true or false to determine visibility of target frame	
	if self.db.char.tfVisible then
		PlayerFrameRemoval:showTarget()
	else 
		PlayerFrameRemoval:hideTarget()
	end
end

-- When toggled checks whether the player frame is visible or not and changes visibility appropriately
function PlayerFrameRemoval:togPlayer(info)
inCombat = InCombatLockdown()
	if inCombat == 1 then
		self:Print("Cannot toggle visibility during combat.")
	else
		if self.db.char.pfVisible then
			PlayerFrameRemoval:hidePlayer()
			self.db.char.pfVisible = false
			self:Print("Player frame is now hidden.")
		else	
			PlayerFrameRemoval:showPlayer()
			self.db.char.pfVisible = true
			self:Print("Player frame is now visible.")
		end
	end	
end

-- When toggled checks whether the target frame is visible or not and changes visibility appropriately
function PlayerFrameRemoval:togTarget(info)
inCombat = InCombatLockdown()
	if inCombat == 1 then
		self:Print("Cannot toggle visibility during combat.")
	else
		if self.db.char.tfVisible then		
			PlayerFrameRemoval:hideTarget()
			self.db.char.tfVisible = false			
			self:Print("Target frame is now hidden")
		else
			PlayerFrameRemoval:showTarget()
			self.db.char.tfVisible = true
			self:Print("Target frame is now visible.")
		end
	end
end

-- Checks status of visibility and displays it on the screen
function PlayerFrameRemoval:status(info)
	if self.db.char.pfVisible then
		self:Print("Player frame is visible.")
	else
		self:Print("Player frame is hidden.")
	end
	
	if self.db.char.tfVisible then
		self:Print("Target frame is visible.")
	else
		self:Print("Target frame is hidden.")
	end
	
end

function PlayerFrameRemoval:showPlayer()
	PlayerFrame:Show()
	PlayerFrame:SetScript("OnEvent", PlayerFrame_OnEvent);
	
	if (class == "DEATHKNIGHT") then
		RuneFrame:Show()
		RuneFrame:SetScript("OnEvent", RuneFrame_OnEvent);
	end
end

function PlayerFrameRemoval:hidePlayer()
	PlayerFrame:Hide()
	PlayerFrame:SetScript("OnEvent", nil);
	
	if (class == "DEATHKNIGHT") then
		RuneFrame:Hide()
		RuneFrame:SetScript("OnEvent", nil);
	end
end

-- Shows target frame and combo point frame
function PlayerFrameRemoval:showTarget()
		TargetFrame:Show()
		TargetFrame:SetScript("OnEvent", TargetFrame_OnEvent);
		
		if (class == "ROGUE") then
			ComboFrame:Show()
			ComboFrame:SetScript ("OnEvent", ComboFrame_OnEvent);
		end
end

-- Hides target frame and combo point frame
function PlayerFrameRemoval:hideTarget()
		TargetFrame:Hide()
		TargetFrame:SetScript("OnEvent", nil);
		
		if (class == "ROGUE") then
			ComboFrame:Hide()
			ComboFrame:SetScript ("OnEvent", nil);
		end
end

